==> haskell-safecopy-0.10.4.2-335-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-safecopy.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 safecopy
version:              0.10.4.2
visibility:           public
id:                   safecopy-0.10.4.2-1OavXqGkn2MCuwP9A80CZm
key:                  safecopy-0.10.4.2-1OavXqGkn2MCuwP9A80CZm
license:              LicenseRef-PublicDomain
maintainer:           Lemmih <lemmih@gmail.com>, David Fox <dsf@seereason.com>
author:               David Himmelstrup, Felipe Lessa
homepage:             https://github.com/acid-state/safecopy
synopsis:             Binary serialization with version control.
description:
    An extension to Data.Serialize with built-in version control.

category:             Data, Parsing
abi:                  d6f3bad2001511a5da14a29255a8032c
exposed:              True
exposed-modules:      Data.SafeCopy Data.SafeCopy.Internal
hidden-modules:
    Data.SafeCopy.Instances Data.SafeCopy.SafeCopy Data.SafeCopy.Derive

import-dirs:          /usr/lib/ghc-9.4.8/site-local/safecopy-0.10.4.2
library-dirs:         /usr/lib/ghc-9.4.8/site-local/safecopy-0.10.4.2
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/safecopy-0.10.4.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-safecopy
hs-libraries:         HSsafecopy-0.10.4.2-1OavXqGkn2MCuwP9A80CZm
depends:
    array-0.5.4.0 base-4.17.2.1 bytestring-0.11.5.3
    cereal-0.5.8.3-H9MXf6i1TMkEAfnsx4oYbT containers-0.6.7
    generic-data-1.1.0.0-EXhzFTJXOJB1f9jjgTY3MT
    old-time-1.1.0.4-7kNg8VzooGoExH4yeT9sv9 template-haskell-2.19.0.0
    text-2.0.2 time-1.12.2 transformers-0.5.6.2
    vector-0.13.2.0-KDCTRjRQ0urK2B6TNAGAn8

haddock-interfaces:   /usr/share/doc/haskell-safecopy/html/safecopy.haddock
haddock-html:         /usr/share/doc/haskell-safecopy/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-safecopy-0.10.4.2-336-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-safecopy.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 safecopy
version:              0.10.4.2
visibility:           public
id:                   safecopy-0.10.4.2-Kb7z3Hf6GEHG1xes9VJsQX
key:                  safecopy-0.10.4.2-Kb7z3Hf6GEHG1xes9VJsQX
license:              LicenseRef-PublicDomain
maintainer:           Lemmih <lemmih@gmail.com>, David Fox <dsf@seereason.com>
author:               David Himmelstrup, Felipe Lessa
homepage:             https://github.com/acid-state/safecopy
synopsis:             Binary serialization with version control.
description:
    An extension to Data.Serialize with built-in version control.

category:             Data, Parsing
abi:                  5e1841d873e3c9ef5440dd0386d6364b
exposed:              True
exposed-modules:      Data.SafeCopy Data.SafeCopy.Internal
hidden-modules:
    Data.SafeCopy.Instances Data.SafeCopy.SafeCopy Data.SafeCopy.Derive

import-dirs:          /usr/lib/ghc-9.4.8/site-local/safecopy-0.10.4.2
library-dirs:         /usr/lib/ghc-9.4.8/site-local/safecopy-0.10.4.2
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/safecopy-0.10.4.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-safecopy
hs-libraries:         HSsafecopy-0.10.4.2-Kb7z3Hf6GEHG1xes9VJsQX
depends:
    array-0.5.4.0 base-4.17.2.1 bytestring-0.11.5.3
    cereal-0.5.8.3-H9MXf6i1TMkEAfnsx4oYbT containers-0.6.7
    generic-data-1.1.0.0-2UnsOGncZcp4jtY6lqtNUa
    old-time-1.1.0.4-7kNg8VzooGoExH4yeT9sv9 template-haskell-2.19.0.0
    text-2.0.2 time-1.12.2 transformers-0.5.6.2
    vector-0.13.2.0-KDCTRjRQ0urK2B6TNAGAn8

haddock-interfaces:   /usr/share/doc/haskell-safecopy/html/safecopy.haddock
haddock-html:         /usr/share/doc/haskell-safecopy/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
